@@ -26,9 +26,9 @@ import java.time.Instant;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.Predicate;
+import java.util.function.Supplier;
 
 import org.jboss.as.ejb3.cache.Cache;
 import org.jboss.as.ejb3.cache.Identifiable;
@@ -41,7 +41,6 @@ import org.jboss.ejb.client.NodeAffinity;
 import org.wildfly.clustering.ee.Scheduler;
 import org.wildfly.clustering.ee.cache.scheduler.LinkedScheduledEntries;
 import org.wildfly.clustering.ee.cache.scheduler.LocalScheduler;
-import org.wildfly.clustering.ejb.IdentifierFactory;
 
 /**
  * Simple {@link Cache} implementation using in-memory storage and eager expiration.
@@ -54,22 +53,16 @@ public class SimpleCache<K, V extends Identifiable<K>> implements Cache<K, V>, P
 
     private final ConcurrentMap<K, Entry<V>> entries = new ConcurrentHashMap<>();
     private final StatefulObjectFactory<V> factory;
-    private final IdentifierFactory<K> identifierFactory;
+    private final Supplier<K> identifierFactory;
     private final Duration timeout;
     private final ServerEnvironment environment;
     private final Scheduler<K, Instant> scheduler = new LocalScheduler<>(new LinkedScheduledEntries<>(), this, Duration.ZERO);
 
-    public SimpleCache(StatefulObjectFactory<V> factory, IdentifierFactory<K> identifierFactory, StatefulTimeoutInfo timeout, ServerEnvironment environment) {
+    public SimpleCache(StatefulObjectFactory<V> factory, Supplier<K> identifierFactory, StatefulTimeoutInfo timeout, ServerEnvironment environment) {
         this.factory = factory;
         this.identifierFactory = identifierFactory;
-
         // A value of -1 means the bean will never be removed due to timeout
-        if (timeout == null || timeout.getValue() < 0) {
-            this.timeout = null;
-        } else {
-            this.timeout = Duration.ofMillis(TimeUnit.MILLISECONDS.convert(timeout.getValue(), timeout.getTimeUnit()));
-        }
-
+        this.timeout = (timeout != null && timeout.getValue() >= 0) ? Duration.of(timeout.getValue(), timeout.getTimeUnit().toChronoUnit()) : null;
         this.environment = environment;
     }
 
@@ -98,8 +91,8 @@ public class SimpleCache<K, V extends Identifiable<K>> implements Cache<K, V>, P
     }
 
     @Override
-    public K createIdentifier() {
-        return this.identifierFactory.createIdentifier();
+    public Supplier<K> getIdentifierFactory() {
+        return this.identifierFactory;
     }
 
     @Override
@@ -144,15 +137,16 @@ public class SimpleCache<K, V extends Identifiable<K>> implements Cache<K, V>, P
     public void release(V bean) {
         K id = bean.getId();
         Entry<V> entry = this.entries.get(id);
-        if ((entry != null) && entry.done()) {
-            if (this.timeout != null) {
-                if (!this.timeout.isZero()) {
-                    this.scheduler.schedule(id, Instant.now().plus(this.timeout));
-                } else {
-                    // The Jakarta Enterprise Beans specification allows a 0 timeout, which means the bean is immediately eligible for removal.
-                    // However, removing it directly is faster than scheduling it for immediate removal.
-                    remove(id);
-                }
+        if (entry != null
+                && entry.done()
+                && this.timeout != null) {
+            if (!this.timeout.isZero()) {
+                this.scheduler.schedule(id, Instant.now().plus(this.timeout));
+            } else {
+                // The Jakarta Enterprise Beans specification allows a 0 timeout, which means the bean is immediately eligible
+                // for removal.
+                // However, removing it directly is faster than scheduling it for immediate removal.
+                remove(id);
             }
         }
     }
