@@ -52,7 +52,6 @@ import org.jboss.as.weld.deployment.BeanDeploymentArchiveImpl;
 import org.jboss.as.weld.deployment.BeanDeploymentArchiveImpl.BeanArchiveType;
 import org.jboss.as.weld.deployment.ExplicitBeanArchiveMetadata;
 import org.jboss.as.weld.deployment.ExplicitBeanArchiveMetadataContainer;
-import org.jboss.as.weld.deployment.PropertyReplacingBeansXmlParser;
 import org.jboss.as.weld.deployment.WeldAttachments;
 import org.jboss.as.weld.deployment.processors.UrlScanner.ClassFile;
 import org.jboss.as.weld.discovery.AnnotationType;
@@ -61,12 +60,12 @@ import org.jboss.as.weld.spi.ComponentSupport;
 import org.jboss.as.weld.spi.ModuleServicesProvider;
 import org.jboss.as.weld.util.Reflections;
 import org.jboss.as.weld.util.ServiceLoaders;
+import org.jboss.as.weld.util.Utils;
 import org.jboss.jandex.AnnotationInstance;
 import org.jboss.jandex.ClassInfo;
 import org.jboss.jandex.DotName;
 import org.jboss.jandex.Index;
 import org.jboss.jandex.IndexReader;
-import org.jboss.jandex.Indexer;
 import org.jboss.modules.DependencySpec;
 import org.jboss.modules.Module;
 import org.jboss.modules.ModuleDependencySpec;
@@ -120,11 +119,20 @@ public class ExternalBeanArchiveProcessor implements DeploymentUnitProcessor {
         // This set is used for external bean archives with annotated discovery mode
         final Set<AnnotationType> beanDefiningAnnotations = new HashSet<>(deploymentUnit.getAttachment(WeldAttachments.BEAN_DEFINING_ANNOTATIONS));
 
-        final List<DeploymentUnit> deploymentUnits = new ArrayList<DeploymentUnit>();
+        List<DeploymentUnit> subDeployments = deploymentUnit.getAttachmentList(Attachments.SUB_DEPLOYMENTS);
+        List<DeploymentUnit> deploymentUnits = new ArrayList<>(subDeployments.size() + 1);
         deploymentUnits.add(deploymentUnit);
-        deploymentUnits.addAll(deploymentUnit.getAttachmentList(Attachments.SUB_DEPLOYMENTS));
+        deploymentUnits.addAll(subDeployments);
 
-        PropertyReplacingBeansXmlParser parser = new PropertyReplacingBeansXmlParser(deploymentUnit);
+        List<ClassLoader> loaders = new ArrayList<>(deploymentUnits.size() + 1);
+        loaders.add(WildFlySecurityManager.getClassLoaderPrivileged(WeldDeploymentProcessor.class));
+        for (DeploymentUnit unit : deploymentUnits) {
+            loaders.add(unit.getAttachment(Attachments.MODULE).getClassLoader());
+        }
+
+        BeansXmlParser parser = BeansXmlParserFactory.getPropertyReplacingParser(deploymentUnit,
+                Utils.getRootDeploymentUnit(deploymentUnit).getAttachment(WeldConfiguration.ATTACHMENT_KEY)
+                        .isLegacyEmptyBeansXmlTreatment());
 
         final HashSet<URL> existing = new HashSet<URL>();
 
@@ -160,8 +168,7 @@ public class ExternalBeanArchiveProcessor implements DeploymentUnitProcessor {
             }
         }
 
-        final ServiceLoader<ModuleServicesProvider> moduleServicesProviders = ServiceLoader.load(ModuleServicesProvider.class,
-                WildFlySecurityManager.getClassLoaderPrivileged(WeldDeploymentProcessor.class));
+        Iterable<ModuleServicesProvider> moduleServicesProviders = ServiceLoader.load(ModuleServicesProvider.class, new CompositeClassLoader(loaders));
 
         Set<String> skipPrecalculatedJandexModules = getSkipPrecalculatedJandexModules(deploymentUnit);
 
@@ -173,6 +180,7 @@ public class ExternalBeanArchiveProcessor implements DeploymentUnitProcessor {
             if (module == null) {
                 return;
             }
+
             for (DependencySpec dep : module.getDependencies()) {
                 if (!(dep instanceof ModuleDependencySpec)) {
                     continue;
@@ -299,10 +307,9 @@ public class ExternalBeanArchiveProcessor implements DeploymentUnitProcessor {
                 };
             } else {
                 // Build ClassInfo on the fly
-                Indexer indexer = new Indexer();
                 consumer = (name, classFile) -> {
                     try (InputStream in = classFile.openStream()) {
-                        ClassInfo classInfo = indexer.index(in);
+                        ClassInfo classInfo = Index.singleClass(in);
                         allKnownClasses.add(name);
                         if (classInfo != null && hasBeanDefiningAnnotation(classInfo, beanDefiningAnnotations)) {
                             discoveredBeanClasses.add(name);
@@ -376,7 +383,7 @@ public class ExternalBeanArchiveProcessor implements DeploymentUnitProcessor {
     }
 
     private boolean hasBeanDefiningAnnotation(ClassInfo classInfo, Set<AnnotationType> beanDefiningAnnotations) {
-        Map<DotName, List<AnnotationInstance>> annotationsMap = classInfo.annotations();
+        Map<DotName, List<AnnotationInstance>> annotationsMap = classInfo.annotationsMap();
         for (AnnotationType beanDefiningAnnotation : beanDefiningAnnotations) {
             List<AnnotationInstance> annotations = annotationsMap.get(beanDefiningAnnotation.getName());
             if (annotations != null) {
